globals
[
  R ; payoff from game when agents both cooperate
  S ; payoff from game when agent cooperated and other defected
  T ; payoff from game when agent defected and other cooperated
  P ; payoff from game when both agents defected 
  nrExit ; number games where agents did not play games
  nrCC ; number of games where both agents cooperated
  nrDD ; number of games where both agents defected
  nrCD ; number of games where one agent cooperated and other defected
  avgnrExit 
  avgnrCC
  avgnrDD
  avgnrCD
  avgalpha
  avgbeta
  avgpayoff
]

turtles-own
[
  alpha ; guilt factor of agent
  beta ; pride factor of agent
  payoff ; payoff of games played during a generation
  w ; weights for the nrsymbols + 1 units of the M function
  symbols  ; a list of 0 and 1 that represents the symbols of agents. The length of the list is nrsymbols + 1 since item 0 is a constant of the M equation.
  nrgames ; nrgames played during a generation
  notdrawn? ; is true when agent is drawn and can not be drawn again to determine player B
  alphaparent 
  betaparent
  wparent
  symbolsparent
]


to setup
  ;; (for your model to work with NetLogo's new plotting features,
  ;; __clear-all-and-reset-ticks should be replaced with clear-all at
  ;; the beginning of your setup procedure and reset-ticks at the end
  ;; of the procedure.)
  __clear-all-and-reset-ticks
  set T 2
  set R 1
  set P -1 
  set S -2
  set nrExit 0
  set nrCC 0
  set nrDD 0
  set nrCD 0
  set avgnrExit 0
  set avgnrCC 0
  set avgnrDD 0
  set avgnrCD 0
  set avgalpha 0
  set avgbeta 0
  set avgpayoff 0
  let teller 0
  set-default-shape turtles "dot"
  crt nragents [
    set color red
    set size 5
    let correct 0
    while [correct = 0]
    [
      set alpha random-float 1
      set beta random-float 1
      if alpha > beta [set correct 1]
    ]
    set xcor (alpha * 100)
    set ycor (beta * 100)
    set payoff 0
    set nrgames 0
    set teller 0
    set notdrawn? true
    set w []
    set symbols []
    while [teller <= nrsymbols]
    [
      set w lput 0 w
      ifelse teller = 0 [set symbols lput 1 symbols]
      [ifelse random-float 1.0 < 0.5 [set symbols lput 1 symbols][set symbols lput 0 symbols]]
      set teller teller + 1
    ]
  ]
  do-plots
end

to go
  set nrExit 0
  set nrCC 0
  set nrDD 0
  set nrCD 0
  playgames

  replacement
  ask turtles [
    set xcor (alpha * 100)
    set ycor (beta * 100)
  ]
  do-plots
  ask turtles [
    set payoff 0
    set nrgames 0
    set alphaparent alpha
    set betaparent beta
    set wparent w
    set symbolsparent symbols
  ]
  tick
end

to playgames
  let teller 0
  let M 0
  let EUC 0  ; expected utility to cooperate
  let EUD 0  ; expected utility to defect
  let tellerS 0
  let PTA 0 ; probability agent A has whether agent B will cooperate (trust from A in B)
  let PTB 0 ; probability agent B has whether agent A will cooperate (trust from B in A)
  let PrC 0 ; probability to cooperate
  let decisionA 0
  let decisionB 0
  let agentA 0
  let agentB 0
  let payoffA 0
  let payoffB 0
  let weight 0

  while [teller < gamespg]
  [
    ; draw two random agents
    set agentA one-of turtles
    ask agentA [set notdrawn? false]
    set agentB one-of turtles with [notdrawn?]
    ask agentA [set notdrawn? true]
  
  ; estimate trust of A in B and decision to cooperate or not
    set M item 0 [w] of agentA 
    set tellerS 1
    while [tellerS <= nrsymbols]
    [
      set M M + item tellerS [symbols] of agentB * item tellerS [w] of agentA
      set tellerS tellerS + 1
    ]

    set PTA 1 / (1 + e ^ (- M))
  
    set EUC PTA * R + (1 - PTA) * (S + [beta] of agentA * (T - S))
    set EUD PTA * (T - [alpha] of agentA * (T - S)) + (1 - PTA) * P

    set PrC (e ^ (steepness * EUC)) / ((e ^ (steepness * EUC)) + (e ^ (steepness * EUD)))
    ifelse random-float 1.0 < PrC [set decisionA 1][set decisionA 0]

    ; estimate trust of B in A and decision to cooperate or not
    set M item 0 [w] of agentB 
    set tellerS 1
    while [tellerS <= nrsymbols]
    [
      set M M + item tellerS [symbols] of agentA * item tellerS [w] of agentB
      set tellerS tellerS + 1
    ]
    set PTB 1 / (1 + e ^ (- M))
  
    set EUC PTB * R + (1 - PTB) * (S + [beta] of agentB * (T - S))
    set EUD PTB * (T - [alpha] of agentB * (T - S)) + (1 - PTB) * P
    set PrC (e ^ (steepness * EUC)) / ((e ^ (steepness * EUC)) + (e ^ (steepness * EUD)))
    ifelse random-float 1.0 < PrC [set decisionB 1][set decisionB 0]
  
    ask agentA [set nrgames nrgames + 1]
    ask agentB [set nrgames nrgames + 1]
    
    ; only when both players trust eachother play the game
    ifelse ((random-float 1.0 < PTA) and (random-float 1.0 < PTB))
    [
      if decisionA = 1 and decisionB = 1 [
        ask agentA [set payoff payoff + R] 
        ask agentB [set payoff payoff + R]
        set nrCC nrCC + 1]
      if decisionA = 1 and decisionB = 0 [
        ask agentA [set payoff payoff + S] 
        ask agentB [set payoff payoff + T]
        set nrCD nrCD + 1]
      if decisionA = 0 and decisionB = 1 [
        ask agentA [set payoff payoff + T] 
        ask agentB [set payoff payoff + S]
        set nrCD nrCD + 1]
      if decisionA = 0 and decisionB = 0 [
        ask agentA [set payoff payoff + P] 
        ask agentB [set payoff payoff + P]
        set nrDD nrDD + 1]
  
      ; update weights symbols due to learning
      set tellerS 0
      while [tellerS <= nrsymbols]
      [
        set weight item tellerS [w] of agentA + learningrate * (decisionB - PTA) * item tellerS [symbols] of agentB
        ask agentA [set w replace-item tellerS w weight]
        set tellerS tellerS + 1
      ]
  
      set tellerS 0
      while [tellerS <= nrsymbols]
      [
        set weight item tellerS [w] of agentB + learningrate * (decisionA - PTB) * item tellerS [symbols] of agentA
        ask agentB [set w replace-item tellerS w weight]
        set tellerS tellerS + 1
      ] 
     ][set nrExit nrExit + 1]
    set teller teller + 1
  ]
end

to replacement
  let tellerS 0
  let agentA 0
  let agentB 0

  ask turtles [
    set alphaparent alpha
    set betaparent beta
    set symbolsparent symbols
    set wparent w
    ifelse nrgames > 0
      [set payoff payoff / nrgames][set payoff 0]]
  
  do-plots2
   
  ; new generation is determined. With a probability 'replace' agents are replaced by the winner of a competition. Two agents are randomly drawn and the best agent is chosen. The child agent has a small variation in the traits due to mutations  
  ask turtles [
    ifelse random-float 1.0 < replace [ 
      set agentA one-of turtles
      set agentB one-of turtles
      if [payoff] of agentA > [payoff] of agentB [
        set alpha [alphaparent] of agentA
        set beta [betaparent] of agentA
        set w [wparent] of agentA
        set symbols [symbolsparent] of agentA
     ]
     if [payoff] of agentB > [payoff] of agentA [
       set alpha [alphaparent] of agentB
       set beta [betaparent] of agentB
       set w [wparent] of agentB
       set symbols [symbolsparent] of agentB
     ]
     if [payoff] of agentA = [payoff] of agentB [
       ifelse random-float 1.0 < 0.5 [
         set alpha [alphaparent] of agentA
         set beta [betaparent] of agentA
         set w [wparent] of agentA
         set symbols [symbolsparent] of agentA
       ][
         set alpha [alphaparent] of agentB
         set beta [betaparent] of agentB
         set w [wparent] of agentB
         set symbols [symbolsparent] of agentB
       ]
     ]
     ; mutations 
     set alpha alpha + mutrate-alpha * random-normal 0 1
     if alpha < 0 [set alpha 0]
     if alpha > 1 [set alpha 1]
     set beta beta + mutrate-beta * random-normal 0 1
     if beta < 0 [set beta 0]
     if beta > alpha [set beta alpha]
     
     set tellerS 0
     while [tellerS <= nrsymbols]
     [
       set w replace-item tellerS w (item tellerS w + mutrate-w * random-normal 0 1)
       set tellerS tellerS + 1
     ]
     set tellerS 1
     while [tellerS <= nrsymbols]
     [
       if random-float 1.0 < mutrate-s
       [
         ifelse item tellerS symbols = 0 [set symbols replace-item tellerS symbols 1][set symbols replace-item tellerS symbols 0]
       ]   
       set tellerS tellerS + 1
     ]
   ][
      set alpha alphaparent
      set beta betaparent
      set w wparent
      set symbols symbolsparent 
   ]
 ]
 ask turtles [
   set payoff 0
   set nrgames 0
   set notdrawn? true
 ]
end

to do-plots
  let averagealpha 0
  let averagebeta 0
  let averagepayoff 0

  ask turtles [set averagealpha averagealpha + alpha]
  set-current-plot "alpha"
  plot averagealpha / nragents
  
  ask turtles [set averagebeta averagebeta + beta]
  set-current-plot "beta"
  plot averagebeta / nragents
  
  set-current-plot "fraction"
  set-current-plot-pen "CC"
  plot nrCC / gamespg
  set-current-plot-pen "DD"
  plot nrDD / gamespg
  set-current-plot-pen "CD"
  plot nrCD / gamespg
  set-current-plot-pen "Exit"
  plot nrExit / gamespg
  
  if ticks > 500 [
    set avgnrExit avgnrExit + 0.001 * nrExit
    set avgnrCC avgnrCC + 0.001 * nrCC
    set avgnrDD avgnrDD + 0.001 * nrDD
    set avgnrCD avgnrCD + 0.001 * nrCD
    set avgalpha avgalpha + 0.001 * averagealpha
    set avgbeta avgbeta + 0.001 * averagebeta
    set avgpayoff avgpayoff + 0.001 * averagepayoff
  ]
end

to do-plots2
  let averagepayoff 0
  ask turtles [set averagepayoff averagepayoff + payoff]
  set-current-plot "payoff"
  plot averagepayoff / nragents
  if ticks > 500 [
    set avgpayoff avgpayoff + 0.001 * averagepayoff
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
184
10
699
546
-1
-1
5.0
1
10
1
1
1
0
0
0
1
0
100
0
100
1
1
1
ticks
30.0

BUTTON
11
10
82
43
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
93
10
160
43
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
8
45
176
78
nragents
nragents
2
1000
100
1
1
NIL
HORIZONTAL

SLIDER
7
82
179
115
nrsymbols
nrsymbols
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
9
126
181
159
learningrate
learningrate
0
1
1.5
0.01
1
NIL
HORIZONTAL

SLIDER
10
169
182
202
steepness
steepness
0
5
2
0.1
1
NIL
HORIZONTAL

SLIDER
9
211
181
244
gamespg
gamespg
0
5000
500
1
1
NIL
HORIZONTAL

SLIDER
7
302
179
335
mutrate-s
mutrate-s
0
1
0.05
0.01
1
NIL
HORIZONTAL

SLIDER
6
347
178
380
mutrate-w
mutrate-w
0
1
0.1
0.01
1
NIL
HORIZONTAL

SLIDER
6
392
178
425
mutrate-alpha
mutrate-alpha
0
0.1
0.025
0.005
1
NIL
HORIZONTAL

SLIDER
7
436
179
469
mutrate-beta
mutrate-beta
0
0.1
0.025
0.005
1
NIL
HORIZONTAL

SLIDER
9
251
181
284
nrgenerations
nrgenerations
0
2000
1500
1
1
NIL
HORIZONTAL

SLIDER
9
482
181
515
replace
replace
0
1
0.1
0.01
1
NIL
HORIZONTAL

PLOT
708
10
1026
265
alpha
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
1032
10
1349
265
beta
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
708
271
1027
516
payoff
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
1031
271
1351
517
fraction
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"CC" 1.0 0 -16777216 true "" ""
"CD" 1.0 0 -13345367 true "" ""
"DD" 1.0 0 -2674135 true "" ""
"Exit" 1.0 0 -10899396 true "" ""

@#$#@#$#@
This is a Netlogo implementation of the model described in Janssen, M.A. (2008), Evolution of Cooperation in a One-Shot Prisoner�s Dilemma Based on Recognition of Trustworthy and Untrustworthy Agents, Journal of Economic Behavior and Organization 65: 458-471

The original model was implemented in 2002 in Java. Janssen (2008) includes one error in the table of default parameter values. In the original Java model I used absolute values for alpha and beta between 0 and 4. In the paper I scaled it to values between 0 and 1, relative to the difference between the payoff of S and T. I forgot to adjust the mutation rates of alpha and beta from 0.1 to 0.025.

The results of Janssen (2008) are replicated with this Netlogo version.

The replication is performed by Marco A. Janssen, Arizona State University, March 2008.  
Copyright (C) 2008 M.A. Janssen

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.  
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.  
You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1501"/>
    <metric>avgnrExit</metric>
    <metric>avgnrCC</metric>
    <metric>avgnrDD</metric>
    <metric>avgnrCD</metric>
    <metric>avgalpha</metric>
    <metric>avgbeta</metric>
    <metric>avgpayoff</metric>
    <enumeratedValueSet variable="learningrate">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nragents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nrgenerations">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="steepness">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutrate-alpha">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nrsymbols">
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
      <value value="20"/>
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutrate-w">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutrate-beta">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutrate-s">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gamespg">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 30 225
Line -7500403 true 150 150 270 225

@#$#@#$#@
0
@#$#@#$#@
